```text
  MMGEN-TXSIGN: Sign cryptocoin transactions generated by mmgen-txcreate
  USAGE:        mmgen-txsign [opts] <transaction file>... [seed source]...
  OPTIONS:
  -h, --help            Print this help message
      --longhelp        Print help message for long (global) options
  -a, --autosign        Sign a transaction created for offline autosigning (see
                        ‘mmgen-autosign’)
  -b, --brain-params l,p Use seed length 'l' and hash preset 'p' for
                        brainwallet input
  -d, --outdir       d  Specify an alternate directory 'd' for output
  -D, --tx-id           Display transaction ID and exit
  -e, --echo-passphrase Print passphrase to screen when typing it
  -E, --use-internal-keccak-module Force use of the internal keccak module
  -i, --in-fmt       f  Input is from wallet format 'f' (see FMT CODES below)
  -H, --hidden-incog-input-params f,o  Read hidden incognito data from file
                        'f' at offset 'o' (comma-separated)
  -O, --old-incog-fmt   Specify old-format incognito input
  -l, --seed-len     l  Specify wallet seed length of 'l' bits. This option
                        is required only for brainwallet and incognito inputs
                        with non-standard (< 256-bit) seed lengths.
  -p, --hash-preset p   Use the scrypt hash parameters defined by preset 'p'
                        for password hashing (default: '3')
  -z, --show-hash-presets Show information on available hash presets
  -k, --keys-from-file f Provide additional keys for non-MMGen addresses
  -K, --keygen-backend n Use backend 'n' for public key generation.  Options
                        for BTC: 1:libsecp256k1 [default] 2:python-ecdsa
  -M, --mmgen-keys-from-file f Provide keys for MMGen addresses in a key-
                        address file (output of 'mmgen-keygen'). Permits
                        online signing without an MMGen seed source. The
                        key-address file is also used to verify MMGen-to-BTC
                        mappings, so the user should record its checksum.
  -P, --passwd-file  f  Get MMGen wallet passphrase from file 'f'
  -q, --quiet           Suppress warnings; overwrite files without prompting
  -I, --info            Display information about the transaction and exit
  -t, --terse-info      Like '--info', but produce more concise output
  -u, --subseeds      n The number of subseed pairs to scan for (default: 100,
                        maximum: 1000000). Only the default or first supplied
                        wallet is scanned for subseeds.
  -v, --verbose         Produce more verbose output
  -V, --vsize-adj    f  Adjust transaction's estimated vsize by factor 'f'
  -W, --allow-non-wallet-swap Allow signing of swap transactions that send funds
                        to non-wallet addresses
  -y, --yes             Answer 'yes' to prompts, suppress non-essential output


  Transactions may contain both MMGen or non-MMGen input addresses.

  To sign non-MMGen inputs, a coin daemon wallet dump or flat key list is used
  as the key source (--keys-from-file option).

  To sign MMGen inputs, key data is generated from a seed as with the
  mmgen-addrgen and mmgen-keygen commands.  Alternatively, a key-address file
  may be used (--mmgen-keys-from-file option).

  Multiple wallets or other seed files can be listed on the command line in
  any order.  If the seeds required to sign the transaction’s inputs are not
  found in these files (or in the default wallet), the user will be prompted
  for seed data interactively.

  To prevent an attacker from crafting transactions with bogus MMGen-to-Bitcoin
  address mappings, all outputs to MMGen addresses are verified with a seed
  source.  Therefore, seed files or a key-address file for all MMGen outputs
  must also be supplied on the command line if the data can’t be found in the
  default wallet.

  Seed source files must have the canonical extensions listed in the 'FileExt'
  column below:


  FMT CODES:

    Format             FileExt   Valid codes
    ------             -------   -----------
    BIP39Mnemonic      .bip39    bip39
    Brainwallet        .mmbrain  mmbrain,brainwallet,brain,bw
    DieRollWallet      .b6d      b6d,die,dieroll
    IncogWallet        .mmincog  mmincog,incog,icg,i
    IncogWalletHex     .mmincox  mmincox,incox,incog_hex,ix,xi
    IncogWalletHidden  None      incog_hidden,hincog,ih,hi
    MMGenHexSeedFile   .mmhex    seedhex,hexseed,mmhex
    MMGenMnemonic      .mmwords  mmwords,words,mnemonic,mn,m
    MMGenSeedFile      .mmseed   mmseed,seed,s
    MMGenWallet        .mmdat    wallet,w
    PlainHexSeedFile   .hex      hex,rawhex,plainhex

  MMGEN-WALLET 16.0.0            September 2025                MMGEN-TXSIGN(1)
```
